pub struct TreeCountingCaches {
pub sibling_index: FxHashMap<OpaqueElement, u32>,
pub sibling_count: FxHashMap<OpaqueNode, u32>,
}Expand description
Caches to speed up evalution of tree-counting functions. Separate caches for index and count are used so that they can be populated in a single traversal of an element’s siblings.
TODO(Bug 2046399) - Consider directly using the SelectorCaches instead.
Fields
sibling_index: FxHashMap<OpaqueElement, u32>A cache of element sibling-index() values.
sibling_count: FxHashMap<OpaqueNode, u32>A cache of element sibling-count() values, keyed by the element’s parent node.
Implementations
Sourceimpl TreeCountingCaches
impl TreeCountingCaches
Sourcepub fn get_or_compute(
&mut self,
element_context: &dyn ElementContext,
) -> TreeCountingResult
pub fn get_or_compute( &mut self, element_context: &dyn ElementContext, ) -> TreeCountingResult
Look up the tree-counting function values for the given element. If the element and its parent node are not cached, the values are computed and stored.